@@ -132,7 +132,7 @@ namespace gr {
     y_abs = fabsf(y);
     x_abs = fabsf(x);
     /* don't divide by zero! */
-    if((y_abs < 1.5E-5) && (x_abs < 1.5E-5))
+    if(!((y_abs > 0.0f) || (x_abs > 0.0f)))
       return 0.0;
 
     //z = (y_abs < x_abs ? y_abs / x_abs : x_abs / y_abs);
