@@ -56,14 +56,8 @@ namespace gr {
       int noi = d_vlen*noutput_items;
       
       memcpy(out, input_items[0], noi*sizeof(float));
-      if(is_unaligned()) {
-	for(size_t i = 1; i < input_items.size(); i++)
-	  volk_32f_x2_add_32f_u(out, out, (const float*)input_items[i], noi);
-      }
-      else {
-	for(size_t i = 1; i < input_items.size(); i++)
-	  volk_32f_x2_add_32f_a(out, out, (const float*)input_items[i], noi);
-      }
+      for(size_t i = 1; i < input_items.size(); i++)
+        volk_32f_x2_add_32f(out, out, (const float*)input_items[i], noi);
       return noutput_items;
     }
 
