@@ -54,12 +54,7 @@ namespace gr {
       gr_complex *iptr = (gr_complex *) input_items[0];
       gr_complex *optr = (gr_complex *) output_items[0];
       
-      if(is_unaligned()) {
-	volk_32fc_conjugate_32fc_u(optr, iptr, noutput_items);
-      }
-      else {
-	volk_32fc_conjugate_32fc_a(optr, iptr, noutput_items);
-      }
+      volk_32fc_conjugate_32fc(optr, iptr, noutput_items);
       
       return noutput_items;
     }
