@@ -90,7 +90,7 @@ namespace gr {
           if(s >= d_in_vlens.size()) {
             throw std::runtime_error("Stream numbers in mapping must be less than the number of input streams.");
           }
-          if((index < 0) || (index >= d_in_vlens[s])) {
+          if(index >= d_in_vlens[s]) {
             throw std::runtime_error ("Indices in mapping must be greater than 0 and less than the input vector lengths.");
           }
         }
