@@ -40,7 +40,7 @@ namespace gr {
 	set_taps(taps);
 
 	// Make sure the output sample is always aligned, too.
-	d_output = fft::malloc_float(1);
+	d_output = (float*)volk_malloc(1*sizeof(float), d_align);
       }
       
       fir_filter_fff::~fir_filter_fff()
@@ -48,14 +48,14 @@ namespace gr {
 	// Free all aligned taps
 	if(d_aligned_taps != NULL) {
 	  for(int i = 0; i < d_naligned; i++) {
-	    fft::free(d_aligned_taps[i]);
+	    volk_free(d_aligned_taps[i]);
 	  }
 	  ::free(d_aligned_taps);
 	  d_aligned_taps = NULL;
 	}
 
 	// Free output sample
-	fft::free(d_output);
+	volk_free(d_output);
       }
       
       void
@@ -64,7 +64,7 @@ namespace gr {
 	// Free the taps if already allocated
 	if(d_aligned_taps!= NULL) {
 	  for(int i = 0; i < d_naligned; i++) {
-	    fft::free(d_aligned_taps[i]);
+	    volk_free(d_aligned_taps[i]);
 	  }
 	  ::free(d_aligned_taps);
 	  d_aligned_taps = NULL;
@@ -77,7 +77,7 @@ namespace gr {
 	// Make a set of taps at all possible arch alignments
 	d_aligned_taps = (float**)malloc(d_naligned*sizeof(float*));
 	for(int i = 0; i < d_naligned; i++) {
-	  d_aligned_taps[i] = fft::malloc_float(d_ntaps+d_naligned-1);
+          d_aligned_taps[i] = (float*)volk_malloc((d_ntaps+d_naligned-1)*sizeof(float), d_align);
 	  memset(d_aligned_taps[i], 0, sizeof(float)*(d_ntaps+d_naligned-1));
 	  for(unsigned int j = 0; j < d_ntaps; j++)
 	    d_aligned_taps[i][i+j] = d_taps[j];
@@ -154,7 +154,7 @@ namespace gr {
 	set_taps(taps);
 
 	// Make sure the output sample is always aligned, too.
-	d_output = fft::malloc_complex(1);
+	d_output = (gr_complex*)volk_malloc(1*sizeof(gr_complex), d_align);
       }
       
       fir_filter_ccf::~fir_filter_ccf()
@@ -162,14 +162,14 @@ namespace gr {
 	// Free all aligned taps
 	if(d_aligned_taps != NULL) {
 	  for(int i = 0; i < d_naligned; i++) {
-	    fft::free(d_aligned_taps[i]);
+	    volk_free(d_aligned_taps[i]);
 	  }
 	  ::free(d_aligned_taps);
 	  d_aligned_taps = NULL;
 	}
 
 	// Free output sample
-	fft::free(d_output);
+	volk_free(d_output);
       }
       
       void
@@ -178,7 +178,7 @@ namespace gr {
 	// Free the taps if already allocated
 	if(d_aligned_taps != NULL) {
 	  for(int i = 0; i < d_naligned; i++) {
-	    fft::free(d_aligned_taps[i]);
+	    volk_free(d_aligned_taps[i]);
 	  }
 	  ::free(d_aligned_taps);
 	  d_aligned_taps = NULL;
@@ -191,7 +191,7 @@ namespace gr {
 	// Make a set of taps at all possible arch alignments
 	d_aligned_taps = (float**)malloc(d_naligned*sizeof(float*));
 	for(int i = 0; i < d_naligned; i++) {
-	  d_aligned_taps[i] = fft::malloc_float(d_ntaps+d_naligned-1);
+          d_aligned_taps[i] = (float*)volk_malloc((d_ntaps+d_naligned-1)*sizeof(float), d_align);
 	  memset(d_aligned_taps[i], 0, sizeof(float)*(d_ntaps+d_naligned-1));
 	  for(unsigned int j = 0; j < d_ntaps; j++)
 	    d_aligned_taps[i][i+j] = d_taps[j];
@@ -270,7 +270,7 @@ namespace gr {
 	set_taps(taps);
 
 	// Make sure the output sample is always aligned, too.
-	d_output = fft::malloc_complex(1);
+	d_output = (gr_complex*)volk_malloc(1*sizeof(gr_complex), d_align);
       }
       
       fir_filter_fcc::~fir_filter_fcc()
@@ -278,14 +278,14 @@ namespace gr {
 	// Free all aligned taps
 	if(d_aligned_taps != NULL) {
 	  for(int i = 0; i < d_naligned; i++) {
-	    fft::free(d_aligned_taps[i]);
+	    volk_free(d_aligned_taps[i]);
 	  }
 	  ::free(d_aligned_taps);
 	  d_aligned_taps = NULL;
 	}
 
 	// Free output sample
-	fft::free(d_output);
+	volk_free(d_output);
       }
       
       void
@@ -294,7 +294,7 @@ namespace gr {
 	// Free the taps if already allocated
 	if(d_aligned_taps != NULL) {
 	  for(int i = 0; i < d_naligned; i++) {
-	    fft::free(d_aligned_taps[i]);
+	    volk_free(d_aligned_taps[i]);
 	  }
 	  ::free(d_aligned_taps);
 	  d_aligned_taps = NULL;
@@ -307,7 +307,7 @@ namespace gr {
 	// Make a set of taps at all possible arch alignments
 	d_aligned_taps = (gr_complex**)malloc(d_naligned*sizeof(gr_complex*));
 	for(int i = 0; i < d_naligned; i++) {
-	  d_aligned_taps[i] = fft::malloc_complex(d_ntaps+d_naligned-1);
+          d_aligned_taps[i] = (gr_complex*)volk_malloc((d_ntaps+d_naligned-1)*sizeof(gr_complex), d_align);
 	  memset(d_aligned_taps[i], 0, sizeof(gr_complex)*(d_ntaps+d_naligned-1));
 	  for(unsigned int j = 0; j < d_ntaps; j++)
 	    d_aligned_taps[i][i+j] = d_taps[j];
@@ -386,7 +386,7 @@ namespace gr {
 	set_taps(taps);
 
 	// Make sure the output sample is always aligned, too.
-	d_output = fft::malloc_complex(1);
+	d_output = (gr_complex*)volk_malloc(1*sizeof(gr_complex), d_align);
       }
       
       fir_filter_ccc::~fir_filter_ccc()
@@ -394,14 +394,14 @@ namespace gr {
 	// Free all aligned taps
 	if(d_aligned_taps != NULL) {
 	  for(int i = 0; i < d_naligned; i++) {
-	    fft::free(d_aligned_taps[i]);
+	    volk_free(d_aligned_taps[i]);
 	  }
 	  ::free(d_aligned_taps);
 	  d_aligned_taps = NULL;
 	}
 
 	// Free output sample
-	fft::free(d_output);
+	volk_free(d_output);
       }
       
       void
@@ -410,7 +410,7 @@ namespace gr {
 	// Free the taps if already allocated
 	if(d_aligned_taps != NULL) {
 	  for(int i = 0; i < d_naligned; i++) {
-	    fft::free(d_aligned_taps[i]);
+	    volk_free(d_aligned_taps[i]);
 	  }
 	  ::free(d_aligned_taps);
 	  d_aligned_taps = NULL;
@@ -423,7 +423,7 @@ namespace gr {
 	// Make a set of taps at all possible arch alignments
 	d_aligned_taps = (gr_complex**)malloc(d_naligned*sizeof(gr_complex*));
 	for(int i = 0; i < d_naligned; i++) {
-	  d_aligned_taps[i] = fft::malloc_complex(d_ntaps+d_naligned-1);
+          d_aligned_taps[i] = (gr_complex*)volk_malloc((d_ntaps+d_naligned-1)*sizeof(gr_complex), d_align);
 	  memset(d_aligned_taps[i], 0, sizeof(gr_complex)*(d_ntaps+d_naligned-1));
 	  for(unsigned int j = 0; j < d_ntaps; j++)
 	    d_aligned_taps[i][i+j] = d_taps[j];
@@ -500,7 +500,7 @@ namespace gr {
 	set_taps(taps);
 
 	// Make sure the output sample is always aligned, too.
-	d_output = fft::malloc_complex(1);
+	d_output = (gr_complex*)volk_malloc(1*sizeof(gr_complex), d_align);
       }
       
       fir_filter_scc::~fir_filter_scc()
@@ -508,14 +508,14 @@ namespace gr {
 	// Free all aligned taps
 	if(d_aligned_taps != NULL) {
 	  for(int i = 0; i < d_naligned; i++) {
-	    fft::free(d_aligned_taps[i]);
+	    volk_free(d_aligned_taps[i]);
 	  }
 	  ::free(d_aligned_taps);
 	  d_aligned_taps = NULL;
 	}
 
 	// Free output sample
-	fft::free(d_output);
+	volk_free(d_output);
       }
       
       void
@@ -524,7 +524,7 @@ namespace gr {
 	// Free the taps if already allocated
 	if(d_aligned_taps != NULL) {
 	  for(int i = 0; i < d_naligned; i++) {
-	    fft::free(d_aligned_taps[i]);
+	    volk_free(d_aligned_taps[i]);
 	  }
 	  ::free(d_aligned_taps);
 	  d_aligned_taps = NULL;
@@ -537,7 +537,7 @@ namespace gr {
 	// Make a set of taps at all possible arch alignments
 	d_aligned_taps = (gr_complex**)malloc(d_naligned*sizeof(gr_complex*));
 	for(int i = 0; i < d_naligned; i++) {
-	  d_aligned_taps[i] = fft::malloc_complex(d_ntaps+d_naligned-1);
+          d_aligned_taps[i] = (gr_complex*)volk_malloc((d_ntaps+d_naligned-1)*sizeof(gr_complex), d_align);
 	  memset(d_aligned_taps[i], 0, sizeof(gr_complex)*(d_ntaps+d_naligned-1));
 	  for(unsigned int j = 0; j < d_ntaps; j++)
 	    d_aligned_taps[i][i+j] = d_taps[j];
@@ -615,7 +615,7 @@ namespace gr {
 	set_taps(taps);
 
 	// Make sure the output sample is always aligned, too.
-	d_output = (short*)fft::malloc_float(1);
+	d_output = (short*)volk_malloc(1*sizeof(short), d_align);
       }
       
       fir_filter_fsf::~fir_filter_fsf()
@@ -623,14 +623,14 @@ namespace gr {
       	// Free all aligned taps
 	if(d_aligned_taps != NULL) {
 	  for(int i = 0; i < d_naligned; i++) {
-	    fft::free(d_aligned_taps[i]);
+	    volk_free(d_aligned_taps[i]);
 	  }
 	  ::free(d_aligned_taps);
 	  d_aligned_taps = NULL;
 	}
 
 	// Free output sample
-	fft::free(d_output);
+	volk_free(d_output);
       }
       
       void
@@ -639,7 +639,7 @@ namespace gr {
 	// Free the taps if already allocated
 	if(d_aligned_taps != NULL) {
 	  for(int i = 0; i < d_naligned; i++) {
-	    fft::free(d_aligned_taps[i]);
+	    volk_free(d_aligned_taps[i]);
 	  }
 	  ::free(d_aligned_taps);
 	  d_aligned_taps = NULL;
@@ -652,7 +652,7 @@ namespace gr {
 	// Make a set of taps at all possible arch alignments
 	d_aligned_taps = (float**)malloc(d_naligned*sizeof(float*));
 	for(int i = 0; i < d_naligned; i++) {
-	  d_aligned_taps[i] = fft::malloc_float(d_ntaps+d_naligned-1);
+          d_aligned_taps[i] = (float*)volk_malloc((d_ntaps+d_naligned-1)*sizeof(float), d_align);
 	  memset(d_aligned_taps[i], 0, sizeof(float)*(d_ntaps+d_naligned-1));
 	  for(unsigned int j = 0; j < d_ntaps; j++)
 	    d_aligned_taps[i][i+j] = d_taps[j];
