@@ -26,6 +26,8 @@
 #include <stdexcept>
 #include <vector>
 #include <QtGui/QtGui>
+#include <QtGui/QIntValidator>
+#include <QtGui/QDoubleValidator>
 #include <qwt_symbol.h>
 #include <gnuradio/filter/firdes.h>
 #include <gnuradio/qtgui/qtgui_types.h>
@@ -498,6 +500,16 @@ public:
   ~OtherAction()
   {}
 
+  void setValidator(QValidator *v)
+  {
+    d_text->setValidator(v);
+  }
+
+  void setDiagText(QString text)
+  {
+    d_text->setText(text);
+  }
+
 signals:
   void whichTrigger(const QString &text);
 
@@ -603,11 +615,20 @@ public:
     d_act.push_back(new QAction("1024", this));
     d_act.push_back(new QAction("2048", this));
     d_act.push_back(new QAction("4096", this));
-    d_act.push_back(new QAction("8192", this));
-    d_act.push_back(new QAction("16384", this));
-    d_act.push_back(new QAction("32768", this));
+    //d_act.push_back(new QAction("8192", this));
+    //d_act.push_back(new QAction("16384", this));
+    //d_act.push_back(new QAction("32768", this));
     d_act.push_back(new OtherAction(this));
 
+    d_grp = new QActionGroup(this);
+    for(int t = 0; t < d_act.size(); t++) {
+      d_act[t]->setCheckable(true);
+      d_act[t]->setActionGroup(d_grp);
+    }
+
+    QIntValidator *valid = new QIntValidator(32, 4096, this);
+    ((OtherAction*)d_act[d_act.size()-1])->setValidator(valid);
+
     connect(d_act[0], SIGNAL(triggered()), this, SLOT(get05()));
     connect(d_act[1], SIGNAL(triggered()), this, SLOT(get06()));
     connect(d_act[2], SIGNAL(triggered()), this, SLOT(get07()));
@@ -616,59 +637,78 @@ public:
     connect(d_act[5], SIGNAL(triggered()), this, SLOT(get10()));
     connect(d_act[6], SIGNAL(triggered()), this, SLOT(get11()));
     connect(d_act[7], SIGNAL(triggered()), this, SLOT(get12()));
-    connect(d_act[8], SIGNAL(triggered()), this, SLOT(get13()));
-    connect(d_act[9], SIGNAL(triggered()), this, SLOT(get14()));
-    connect(d_act[10], SIGNAL(triggered()), this, SLOT(get15()));
-    connect(d_act[11], SIGNAL(whichTrigger(const QString&)),
-	     this, SLOT(getOther(const QString&)));
+    //connect(d_act[8], SIGNAL(triggered()), this, SLOT(get13()));
+    //connect(d_act[9], SIGNAL(triggered()), this, SLOT(get14()));
+    //connect(d_act[10], SIGNAL(triggered()), this, SLOT(get15()));
+    connect(d_act[8], SIGNAL(whichTrigger(const QString&)),
+            this, SLOT(getOther(const QString&)));
 
-     QListIterator<QAction*> i(d_act);
-     while(i.hasNext()) {
-       QAction *a = i.next();
-       addAction(a);
-     }
-   }
+    QListIterator<QAction*> i(d_act);
+    while(i.hasNext()) {
+      QAction *a = i.next();
+      addAction(a);
+    }
+  }
 
-   ~FFTSizeMenu()
-   {}
+  ~FFTSizeMenu()
+  {}
 
-   int getNumActions() const
-   {
-     return d_act.size();
-   }
+  int getNumActions() const
+  {
+    return d_act.size();
+  }
 
-   QAction * getAction(int which)
-   {
-     if(which < d_act.size())
-       return d_act[which];
-     else
-       throw std::runtime_error("FFTSizeMenu::getAction: which out of range.\n");
-   }
+  QAction * getAction(int which)
+  {
+    if(which < d_act.size())
+      return d_act[which];
+    else
+      throw std::runtime_error("FFTSizeMenu::getAction: which out of range.\n");
+  }
 
- signals:
-   void whichTrigger(int size);
+  QAction * getActionFromSize(int size)
+  {
+    float ipt;
+    float which = logf(static_cast<float>(size))/logf(2.0) - 5;
+    // If we're a predefined value
+    if(modff(which,&ipt) == 0) {
+      if(which < d_act.size()-1)
+        return d_act[static_cast<int>(which)];
+      else
+        throw std::runtime_error("FFTSizeMenu::getActionFromString: which out of range.\n");
+    }
+    // Or a non-predefined value, return Other
+    else {
+      ((OtherAction*)d_act[d_act.size()-1])->setDiagText(QString().setNum(size));
+      return d_act[d_act.size()-1];
+    }
+  }
 
- public slots:
-   void get05() { emit whichTrigger(32); }
-   void get06() { emit whichTrigger(64); }
-   void get07() { emit whichTrigger(128); }
-   void get08() { emit whichTrigger(256); }
-   void get09() { emit whichTrigger(512); }
-   void get10() { emit whichTrigger(1024); }
-   void get11() { emit whichTrigger(2048); }
-   void get12() { emit whichTrigger(4096); }
-   void get13() { emit whichTrigger(8192); }
-   void get14() { emit whichTrigger(16384); }
-   void get15() { emit whichTrigger(32768); }
-   void getOther(const QString &str) 
-   {
-     int value = str.toInt();
-     emit whichTrigger(value);
-   }
+signals:
+  void whichTrigger(int size);
+
+public slots:
+  void get05() { emit whichTrigger(32); }
+  void get06() { emit whichTrigger(64); }
+  void get07() { emit whichTrigger(128); }
+  void get08() { emit whichTrigger(256); }
+  void get09() { emit whichTrigger(512); }
+  void get10() { emit whichTrigger(1024); }
+  void get11() { emit whichTrigger(2048); }
+  void get12() { emit whichTrigger(4096); }
+  //void get13() { emit whichTrigger(8192); }
+  //void get14() { emit whichTrigger(16384); }
+  //void get15() { emit whichTrigger(32768); }
+  void getOther(const QString &str) 
+  {
+    int value = str.toInt();
+    emit whichTrigger(value);
+  }
 
 private:
   QList<QAction *> d_act;
   OtherAction *d_other;
+  QActionGroup *d_grp;
 };
 
 
@@ -683,50 +723,83 @@ public:
   FFTAverageMenu(QWidget *parent)
     : QMenu("FFT Average", parent)
   {
+    d_off = 1.0;
+    d_high = 0.05;
+    d_medium = 0.1;
+    d_low = 0.2;
+
     d_act.push_back(new QAction("Off", this));
     d_act.push_back(new QAction("High", this));
     d_act.push_back(new QAction("Medium", this));
     d_act.push_back(new QAction("Low", this));
     d_act.push_back(new OtherAction(this));
 
+    d_grp = new QActionGroup(this);
+    for(int t = 0; t < d_act.size(); t++) {
+      d_act[t]->setCheckable(true);
+      d_act[t]->setActionGroup(d_grp);
+    }
+    d_act[0]->setChecked(true);
+
+    QDoubleValidator *valid = new QDoubleValidator(0.0, 1.0, 2, this);
+    ((OtherAction*)d_act[d_act.size()-1])->setValidator(valid);
+
     connect(d_act[0], SIGNAL(triggered()), this, SLOT(getOff()));
     connect(d_act[1], SIGNAL(triggered()), this, SLOT(getHigh()));
     connect(d_act[2], SIGNAL(triggered()), this, SLOT(getMedium()));
     connect(d_act[3], SIGNAL(triggered()), this, SLOT(getLow()));
     connect(d_act[4], SIGNAL(whichTrigger(const QString&)),
-	     this, SLOT(getOther(const QString&)));
+            this, SLOT(getOther(const QString&)));
 
-     QListIterator<QAction*> i(d_act);
-     while(i.hasNext()) {
-       QAction *a = i.next();
-       addAction(a);
-     }
-   }
+    QListIterator<QAction*> i(d_act);
+    while(i.hasNext()) {
+      QAction *a = i.next();
+      addAction(a);
+    }
+  }
 
-   ~FFTAverageMenu()
-   {}
+  ~FFTAverageMenu()
+  {}
 
-   int getNumActions() const
-   {
-     return d_act.size();
-   }
+  int getNumActions() const
+  {
+    return d_act.size();
+  }
 
-   QAction * getAction(int which)
-   {
-     if(which < d_act.size())
-       return d_act[which];
-     else
-       throw std::runtime_error("FFTSizeMenu::getAction: which out of range.\n");
-   }
+  QAction * getAction(int which)
+  {
+    if(which < d_act.size())
+      return d_act[which];
+    else
+      throw std::runtime_error("FFTSizeMenu::getAction: which out of range.\n");
+  }
+
+  QAction * getActionFromAvg(float avg)
+  {
+    int which = 0;
+    if(avg == d_off)
+      which = 0;
+    else if(avg == d_high)
+      which = 1;
+    else if(avg == d_medium)
+      which = 2;
+    else if(avg == d_low)
+      which = 3;
+    else {
+      ((OtherAction*)d_act[d_act.size()-1])->setDiagText(QString().setNum(avg));
+      which = 4;
+    }
+    return d_act[static_cast<int>(which)];
+  }
 
  signals:
    void whichTrigger(float alpha);
 
  public slots:
-   void getOff() { emit whichTrigger(1.0); }
-   void getHigh() { emit whichTrigger(0.05); }
-   void getMedium() { emit whichTrigger(0.1); }
-   void getLow() { emit whichTrigger(0.2); }
+   void getOff() { emit whichTrigger(d_off); }
+   void getHigh() { emit whichTrigger(d_high); }
+   void getMedium() { emit whichTrigger(d_medium); }
+   void getLow() { emit whichTrigger(d_low); }
    void getOther(const QString &str) 
    {
      float value = str.toFloat();
@@ -736,6 +809,8 @@ public:
 private:
   QList<QAction *> d_act;
   OtherAction *d_other;
+  QActionGroup *d_grp;
+  float d_off, d_high, d_medium, d_low;
 };
 
 
@@ -757,6 +832,13 @@ public:
     d_act.push_back(new QAction("Blackman-harris", this));
     d_act.push_back(new QAction("Rectangular", this));
     d_act.push_back(new QAction("Kaiser", this));
+    d_act.push_back(new QAction("Flat-top", this));
+
+    d_grp = new QActionGroup(this);
+    for(int t = 0; t < d_act.size(); t++) {
+      d_act[t]->setCheckable(true);
+      d_act[t]->setActionGroup(d_grp);
+    }
 
     connect(d_act[0], SIGNAL(triggered()), this, SLOT(getNone()));
     connect(d_act[1], SIGNAL(triggered()), this, SLOT(getHamming()));
@@ -765,6 +847,7 @@ public:
     connect(d_act[4], SIGNAL(triggered()), this, SLOT(getBlackmanharris()));
     connect(d_act[5], SIGNAL(triggered()), this, SLOT(getRectangular()));
     connect(d_act[6], SIGNAL(triggered()), this, SLOT(getKaiser()));
+    connect(d_act[7], SIGNAL(triggered()), this, SLOT(getFlattop()));
 
     QListIterator<QAction*> i(d_act);
     while(i.hasNext()) {
@@ -789,6 +872,22 @@ public:
       throw std::runtime_error("FFTWindowMenu::getAction: which out of range.\n");
   }
 
+  QAction * getActionFromWindow(gr::filter::firdes::win_type type)
+  {
+    int which = 0;
+    switch(static_cast<int>(type)) {
+    case((gr::filter::firdes::WIN_NONE)): which = 0; break;
+    case((gr::filter::firdes::WIN_HAMMING)): which = 1; break;
+    case((gr::filter::firdes::WIN_HANN)): which = 2; break;
+    case((gr::filter::firdes::WIN_BLACKMAN)): which = 3; break;
+    case((gr::filter::firdes::WIN_BLACKMAN_hARRIS)): which = 4; break;
+    case((gr::filter::firdes::WIN_RECTANGULAR)): which = 5; break;
+    case((gr::filter::firdes::WIN_KAISER)): which = 6; break;
+    case((gr::filter::firdes::WIN_FLATTOP)): which = 7; break;
+    }
+    return d_act[which];
+  }
+
 signals:
   void whichTrigger(const gr::filter::firdes::win_type type);
 
@@ -800,9 +899,11 @@ public slots:
   void getBlackmanharris() { emit whichTrigger(gr::filter::firdes::WIN_BLACKMAN_hARRIS); }
   void getRectangular() { emit whichTrigger(gr::filter::firdes::WIN_RECTANGULAR); }
   void getKaiser() { emit whichTrigger(gr::filter::firdes::WIN_KAISER); }
+  void getFlattop() { emit whichTrigger(gr::filter::firdes::WIN_FLATTOP); }
 
 private:
   QList<QAction *> d_act;
+  QActionGroup *d_grp;
   int d_which;
 };
 
