@@ -27,6 +27,7 @@
 #include <QColor>
 #include <cmath>
 #include <iostream>
+#include <stdexcept>
 #include <QDebug>
 
 DisplayPlot::DisplayPlot(int nplots, QWidget* parent)
@@ -81,11 +82,19 @@ DisplayPlot::DisplayPlot(int nplots, QWidget* parent)
   sd->setMinimumExtent( fm.width("100.00") );
 
   QwtLegend* legendDisplay = new QwtLegend(this);
+
+#if QWT_VERSION < 0x060100
   legendDisplay->setItemMode(QwtLegend::CheckableItem);
   insertLegend(legendDisplay);
-
   connect(this, SIGNAL(legendChecked(QwtPlotItem *, bool)),
 	  this, SLOT(legendEntryChecked(QwtPlotItem *, bool)));
+#else /* QWT_VERSION < 0x060100 */
+  legendDisplay->setDefaultItemMode(QwtLegendData::Checkable);
+  insertLegend(legendDisplay);
+  connect(legendDisplay, SIGNAL(checked(const QVariant&, bool, int)),
+	  this, SLOT(legendEntryChecked(const QVariant&, bool, int)));
+#endif /* QWT_VERSION < 0x060100 */
+
 }
 
 DisplayPlot::~DisplayPlot()
@@ -403,6 +412,16 @@ void DisplayPlot::legendEntryChecked(QwtPlotItem* plotItem, bool on)
   replot();
 }
 
+void DisplayPlot::legendEntryChecked(const QVariant &plotItem, bool on, int index)
+{
+#if QWT_VERSION < 0x060100
+  std::runtime_error("DisplayPlot::legendEntryChecked with QVariant not enabled in this version of QWT.\n");
+#else
+  QwtPlotItem *p = infoToItem(plotItem);
+  legendEntryChecked(p, on);
+#endif /* QWT_VERSION < 0x060100 */
+}
+
 void
 DisplayPlot::onPickerPointSelected(const QwtDoublePoint & p)
 {
