@@ -26,14 +26,14 @@
 
 #include "const_sink_c_impl.h"
 #include <gnuradio/io_signature.h>
+#include <gnuradio/prefs.h>
 #include <string.h>
 #include <volk/volk.h>
-#include <gnuradio/fft/fft.h>
 #include <qwt_symbol.h>
 
 namespace gr {
   namespace qtgui {
-    
+
     const_sink_c::sptr
     const_sink_c::make(int size,
 		       const std::string &name,
@@ -60,15 +60,17 @@ namespace gr {
       // http://harmattan-dev.nokia.com/docs/library/html/qt4/qapplication.html
       d_argc = 1;
       d_argv = new char;
-      d_argv = '\0';
+      d_argv[0] = '\0';
 
       d_main_gui = NULL;
 
       d_index = 0;
 
       for(int i = 0; i < d_nconnections; i++) {
-	d_residbufs_real.push_back(fft::malloc_double(d_size));
-	d_residbufs_imag.push_back(fft::malloc_double(d_size));
+	d_residbufs_real.push_back((double*)volk_malloc(d_size*sizeof(double),
+                                                        volk_get_alignment()));
+	d_residbufs_imag.push_back((double*)volk_malloc(d_size*sizeof(double),
+                                                        volk_get_alignment()));
 	memset(d_residbufs_real[i], 0, d_size*sizeof(double));
 	memset(d_residbufs_imag[i], 0, d_size*sizeof(double));
       }
@@ -88,8 +90,8 @@ namespace gr {
 
       // d_main_gui is a qwidget destroyed with its parent
       for(int i = 0; i < d_nconnections; i++) {
-	fft::free(d_residbufs_real[i]);
-	fft::free(d_residbufs_imag[i]);
+	volk_free(d_residbufs_real[i]);
+	volk_free(d_residbufs_imag[i]);
       }
 
       delete d_argv;
@@ -108,9 +110,18 @@ namespace gr {
 	d_qApplication = qApp;
       }
       else {
+        std::string style = prefs::singleton()->get_string("qtgui", "style", "raster");
+        QApplication::setGraphicsSystem(QString(style.c_str()));
 	d_qApplication = new QApplication(d_argc, &d_argv);
       }
 
+      // If a style sheet is set in the prefs file, enable it here.
+      std::string qssfile = prefs::singleton()->get_string("qtgui","qss","");
+      if(qssfile.size() > 0) {
+        QString sstext = get_qt_style_sheet(QString(qssfile.c_str()));
+        d_qApplication->setStyleSheet(sstext);
+      }
+
       d_main_gui = new ConstellationDisplayForm(d_nconnections, d_parent);
       d_main_gui->setNPoints(d_size);
       // initialize update time to 10 times a second
@@ -129,6 +140,7 @@ namespace gr {
       return d_main_gui;
     }
 
+#ifdef ENABLE_PYTHON
     PyObject*
     const_sink_c_impl::pyqwidget()
     {
@@ -136,6 +148,7 @@ namespace gr {
       PyObject *retarg = Py_BuildValue("N", w);
       return retarg;
     }
+#endif
 
     void
     const_sink_c_impl::set_y_axis(double min, double max)
@@ -257,17 +270,19 @@ namespace gr {
       if(newsize != d_size) {
 	// Resize residbuf and replace data
 	for(int i = 0; i < d_nconnections; i++) {
-	  fft::free(d_residbufs_real[i]);
-	  fft::free(d_residbufs_imag[i]);
-	  d_residbufs_real[i] = fft::malloc_double(newsize);
-	  d_residbufs_imag[i] = fft::malloc_double(newsize);
+	  volk_free(d_residbufs_real[i]);
+	  volk_free(d_residbufs_imag[i]);
+	  d_residbufs_real[i] = (double*)volk_malloc(newsize*sizeof(double),
+                                                     volk_get_alignment());
+	  d_residbufs_imag[i] = (double*)volk_malloc(newsize*sizeof(double),
+                                                     volk_get_alignment());
 
 	  memset(d_residbufs_real[i], 0, newsize*sizeof(double));
 	  memset(d_residbufs_imag[i], 0, newsize*sizeof(double));
 	}
 
-	// Set new size and reset buffer index 
-	// (throws away any currently held data, but who cares?) 
+	// Set new size and reset buffer index
+	// (throws away any currently held data, but who cares?)
 	d_size = newsize;
 	d_index = 0;
 
