@@ -26,13 +26,14 @@
 
 #include "freq_sink_c_impl.h"
 #include <gnuradio/io_signature.h>
+#include <gnuradio/prefs.h>
 #include <string.h>
 #include <volk/volk.h>
 #include <qwt_symbol.h>
 
 namespace gr {
   namespace qtgui {
-    
+
     freq_sink_c::sptr
     freq_sink_c::make(int fftsize, int wintype,
 		      double fc, double bw,
@@ -66,7 +67,7 @@ namespace gr {
       // http://harmattan-dev.nokia.com/docs/library/html/qt4/qapplication.html
       d_argc = 1;
       d_argv = new char;
-      d_argv = '\0';
+      d_argv[0] = '\0';
 
       d_main_gui = NULL;
 
@@ -75,13 +76,16 @@ namespace gr {
       d_shift = true;
 
       d_fft = new fft::fft_complex(d_fftsize, true);
-      d_fbuf = fft::malloc_float(d_fftsize);
+      d_fbuf = (float*)volk_malloc(d_fftsize*sizeof(float),
+                                   volk_get_alignment());
       memset(d_fbuf, 0, d_fftsize*sizeof(float));
 
       d_index = 0;
       for(int i = 0; i < d_nconnections; i++) {
-	d_residbufs.push_back(fft::malloc_complex(d_fftsize));
-	d_magbufs.push_back(fft::malloc_double(d_fftsize));
+	d_residbufs.push_back((gr_complex*)volk_malloc(d_fftsize*sizeof(gr_complex),
+                                                       volk_get_alignment()));
+	d_magbufs.push_back((double*)volk_malloc(d_fftsize*sizeof(double),
+                                                 volk_get_alignment()));
 
 	memset(d_residbufs[i], 0, d_fftsize*sizeof(gr_complex));
 	memset(d_magbufs[i], 0, d_fftsize*sizeof(double));
@@ -98,11 +102,11 @@ namespace gr {
         d_main_gui->close();
 
       for(int i = 0; i < d_nconnections; i++) {
-	fft::free(d_residbufs[i]);
-	fft::free(d_magbufs[i]);
+	volk_free(d_residbufs[i]);
+	volk_free(d_magbufs[i]);
       }
       delete d_fft;
-      fft::free(d_fbuf);
+      volk_free(d_fbuf);
 
       delete d_argv;
     }
@@ -129,7 +133,16 @@ namespace gr {
 	d_qApplication = qApp;
       }
       else {
-	d_qApplication = new QApplication(d_argc, &d_argv);
+        std::string style = prefs::singleton()->get_string("qtgui", "style", "raster");
+        QApplication::setGraphicsSystem(QString(style.c_str()));
+        d_qApplication = new QApplication(d_argc, &d_argv);
+      }
+
+      // If a style sheet is set in the prefs file, enable it here.
+      std::string qssfile = prefs::singleton()->get_string("qtgui","qss","");
+      if(qssfile.size() > 0) {
+        QString sstext = get_qt_style_sheet(QString(qssfile.c_str()));
+        d_qApplication->setStyleSheet(sstext);
       }
 
       d_main_gui = new FreqDisplayForm(d_nconnections, d_parent);
@@ -153,6 +166,7 @@ namespace gr {
       return d_main_gui;
     }
 
+#ifdef ENABLE_PYTHON
     PyObject*
     freq_sink_c_impl::pyqwidget()
     {
@@ -160,6 +174,7 @@ namespace gr {
       PyObject *retarg = Py_BuildValue("N", w);
       return retarg;
     }
+#endif
 
     void
     freq_sink_c_impl::set_fft_size(const int fftsize)
@@ -172,7 +187,7 @@ namespace gr {
     {
       return d_fftsize;
     }
- 
+
     void
     freq_sink_c_impl::set_fft_average(const float fftavg)
     {
@@ -340,8 +355,8 @@ namespace gr {
     freq_sink_c_impl::fft(float *data_out, const gr_complex *data_in, int size)
     {
       if(d_window.size()) {
-	volk_32fc_32f_multiply_32fc_a(d_fft->get_inbuf(), data_in,
-				      &d_window.front(), size);
+	volk_32fc_32f_multiply_32fc(d_fft->get_inbuf(), data_in,
+                                    &d_window.front(), size);
       }
       else {
 	memcpy(d_fft->get_inbuf(), data_in, sizeof(gr_complex)*size);
@@ -349,8 +364,8 @@ namespace gr {
 
       d_fft->execute();     // compute the fft
 
-      volk_32fc_s32f_x2_power_spectral_density_32f_a(data_out, d_fft->get_outbuf(),
-						     size, 1.0, size);
+      volk_32fc_s32f_x2_power_spectral_density_32f(data_out, d_fft->get_outbuf(),
+                                                   size, 1.0, size);
 
       // Perform shift operation
       unsigned int len = (unsigned int)(floor(size/2.0));
@@ -392,18 +407,20 @@ namespace gr {
       if(newfftsize != d_fftsize) {
 	// Resize residbuf and replace data
 	for(int i = 0; i < d_nconnections; i++) {
-	  fft::free(d_residbufs[i]);
-	  fft::free(d_magbufs[i]);
+	  volk_free(d_residbufs[i]);
+	  volk_free(d_magbufs[i]);
 
-	  d_residbufs[i] = fft::malloc_complex(newfftsize);
-	  d_magbufs[i] = fft::malloc_double(newfftsize);
+	  d_residbufs[i] = (gr_complex*)volk_malloc(newfftsize*sizeof(gr_complex),
+                                                    volk_get_alignment());
+	  d_magbufs[i] = (double*)volk_malloc(newfftsize*sizeof(double),
+                                              volk_get_alignment());
 
 	  memset(d_residbufs[i], 0, newfftsize*sizeof(gr_complex));
 	  memset(d_magbufs[i], 0, newfftsize*sizeof(double));
 	}
 
-	// Set new fft size and reset buffer index 
-	// (throws away any currently held data, but who cares?) 
+	// Set new fft size and reset buffer index
+	// (throws away any currently held data, but who cares?)
 	d_fftsize = newfftsize;
 	d_index = 0;
 
@@ -413,9 +430,10 @@ namespace gr {
 	// Reset FFTW plan for new size
 	delete d_fft;
 	d_fft = new fft::fft_complex(d_fftsize, true);
-    
-	fft::free(d_fbuf);
-	d_fbuf = fft::malloc_float(d_fftsize);
+
+	volk_free(d_fbuf);
+	d_fbuf = (float*)volk_malloc(d_fftsize*sizeof(float),
+                                     volk_get_alignment());
 	memset(d_fbuf, 0, d_fftsize*sizeof(float));
       }
     }
@@ -451,7 +469,7 @@ namespace gr {
               }
               //volk_32f_convert_64f_a(d_magbufs[n], d_fbuf, d_fftsize);
             }
-      
+
 	    d_last_time = gr::high_res_timer_now();
 	    d_qApplication->postEvent(d_main_gui,
 				      new FreqUpdateEvent(d_magbufs, d_fftsize));
