@@ -32,7 +32,7 @@
 
 namespace gr {
   namespace qtgui {
-    
+
     class QTGUI_API freq_sink_c_impl : public freq_sink_c
     {
     private:
@@ -84,7 +84,10 @@ namespace gr {
 
       void exec_();
       QWidget*  qwidget();
+
+#ifdef ENABLE_PYTHON
       PyObject* pyqwidget();
+#endif
 
       void set_fft_size(const int fftsize);
       int fft_size() const;
