@@ -39,18 +39,18 @@ FreqDisplayForm::FreqDisplayForm(int nplots, QWidget* parent)
   d_num_real_data_points = 1024;
   d_fftsize = 1024;
   d_fftavg = 1.0;
-  
-  FFTSizeMenu *sizemenu = new FFTSizeMenu(this);
-  FFTAverageMenu *avgmenu = new FFTAverageMenu(this);
-  FFTWindowMenu *winmenu = new FFTWindowMenu(this);
-  d_menu->addMenu(sizemenu);
-  d_menu->addMenu(avgmenu);
-  d_menu->addMenu(winmenu);
-  connect(sizemenu, SIGNAL(whichTrigger(int)),
+
+  d_sizemenu = new FFTSizeMenu(this);
+  d_avgmenu = new FFTAverageMenu(this);
+  d_winmenu = new FFTWindowMenu(this);
+  d_menu->addMenu(d_sizemenu);
+  d_menu->addMenu(d_avgmenu);
+  d_menu->addMenu(d_winmenu);
+  connect(d_sizemenu, SIGNAL(whichTrigger(int)),
 	  this, SLOT(setFFTSize(const int)));
-  connect(avgmenu, SIGNAL(whichTrigger(float)),
+  connect(d_avgmenu, SIGNAL(whichTrigger(float)),
 	  this, SLOT(setFFTAverage(const float)));
-  connect(winmenu, SIGNAL(whichTrigger(gr::filter::firdes::win_type)),
+  connect(d_winmenu, SIGNAL(whichTrigger(gr::filter::firdes::win_type)),
 	  this, SLOT(setFFTWindowType(const gr::filter::firdes::win_type)));
 
   Reset();
@@ -120,6 +120,7 @@ void
 FreqDisplayForm::setFFTSize(const int newsize)
 {
   d_fftsize = newsize;
+  d_sizemenu->getActionFromSize(newsize)->setChecked(true);
   getPlot()->replot();
 }
 
@@ -127,6 +128,7 @@ void
 FreqDisplayForm::setFFTAverage(const float newavg)
 {
   d_fftavg = newavg;
+  d_avgmenu->getActionFromAvg(newavg)->setChecked(true);
   getPlot()->replot();
 }
 
@@ -134,6 +136,7 @@ void
 FreqDisplayForm::setFFTWindowType(const gr::filter::firdes::win_type newwin)
 {
   d_fftwintype = newwin;
+  d_winmenu->getActionFromWindow(newwin)->setChecked(true);
   getPlot()->replot();
 }
 
