@@ -26,14 +26,14 @@
 
 #include "histogram_sink_f_impl.h"
 #include <gnuradio/io_signature.h>
+#include <gnuradio/prefs.h>
 #include <string.h>
 #include <volk/volk.h>
-#include <gnuradio/fft/fft.h>
 #include <qwt_symbol.h>
 
 namespace gr {
   namespace qtgui {
-    
+
     histogram_sink_f::sptr
     histogram_sink_f::make(int size, int bins,
                            double xmin, double xmax,
@@ -63,14 +63,15 @@ namespace gr {
       // http://harmattan-dev.nokia.com/docs/library/html/qt4/qapplication.html
       d_argc = 1;
       d_argv = new char;
-      d_argv = '\0';
+      d_argv[0] = '\0';
 
       d_main_gui = NULL;
 
       d_index = 0;
 
       for(int i = 0; i < d_nconnections; i++) {
-	d_residbufs.push_back(fft::malloc_double(d_size));
+	d_residbufs.push_back((double*)volk_malloc(d_size*sizeof(double),
+                                                   volk_get_alignment()));
 	memset(d_residbufs[i], 0, d_size*sizeof(double));
       }
 
@@ -89,7 +90,7 @@ namespace gr {
 
       // d_main_gui is a qwidget destroyed with its parent
       for(int i = 0; i < d_nconnections; i++) {
-	fft::free(d_residbufs[i]);
+	volk_free(d_residbufs[i]);
       }
 
       delete d_argv;
@@ -108,9 +109,18 @@ namespace gr {
 	d_qApplication = qApp;
       }
       else {
+        std::string style = prefs::singleton()->get_string("qtgui", "style", "raster");
+        QApplication::setGraphicsSystem(QString(style.c_str()));
 	d_qApplication = new QApplication(d_argc, &d_argv);
       }
 
+      // If a style sheet is set in the prefs file, enable it here.
+      std::string qssfile = prefs::singleton()->get_string("qtgui","qss","");
+      if(qssfile.size() > 0) {
+        QString sstext = get_qt_style_sheet(QString(qssfile.c_str()));
+        d_qApplication->setStyleSheet(sstext);
+      }
+
       d_main_gui = new HistogramDisplayForm(d_nconnections, d_parent);
       d_main_gui->setNumBins(d_bins);
       d_main_gui->setNPoints(d_size);
@@ -132,6 +142,7 @@ namespace gr {
       return d_main_gui;
     }
 
+#ifdef ENABLE_PYTHON
     PyObject*
     histogram_sink_f_impl::pyqwidget()
     {
@@ -139,6 +150,7 @@ namespace gr {
       PyObject *retarg = Py_BuildValue("N", w);
       return retarg;
     }
+#endif
 
     void
     histogram_sink_f_impl::set_y_axis(double min, double max)
@@ -260,14 +272,15 @@ namespace gr {
       if(newsize != d_size) {
 	// Resize residbuf and replace data
 	for(int i = 0; i < d_nconnections; i++) {
-	  fft::free(d_residbufs[i]);
-	  d_residbufs[i] = fft::malloc_double(newsize);
+	  volk_free(d_residbufs[i]);
+	  d_residbufs[i] = (double*)volk_malloc(newsize*sizeof(double),
+                                                volk_get_alignment());
 
 	  memset(d_residbufs[i], 0, newsize*sizeof(double));
 	}
 
-	// Set new size and reset buffer index 
-	// (throws away any currently held data, but who cares?) 
+	// Set new size and reset buffer index
+	// (throws away any currently held data, but who cares?)
 	d_size = newsize;
 	d_index = 0;
 
