@@ -26,12 +26,13 @@
 
 #include "sink_c_impl.h"
 #include <gnuradio/io_signature.h>
+#include <gnuradio/prefs.h>
 #include <string.h>
 #include <volk/volk.h>
 
 namespace gr {
   namespace qtgui {
-    
+
     sink_c::sptr
     sink_c::make(int fftsize, int wintype,
 		 double fc, double bw,
@@ -70,7 +71,7 @@ namespace gr {
       // http://harmattan-dev.nokia.com/docs/library/html/qt4/qapplication.html
       d_argc = 1;
       d_argv = new char;
-      d_argv = '\0';
+      d_argv[0] = '\0';
 
       d_main_gui = NULL;
 
@@ -78,11 +79,13 @@ namespace gr {
       // this is usually desired when plotting
       d_shift = true;
 
-      d_fft = new fft::fft_complex (d_fftsize, true);
+      d_fft = new fft::fft_complex(d_fftsize, true);
 
       d_index = 0;
-      d_residbuf = new gr_complex[d_fftsize];
-      d_magbuf = new float[d_fftsize];
+      d_residbuf = (gr_complex*)volk_malloc(d_fftsize*sizeof(gr_complex),
+                                            volk_get_alignment());
+      d_magbuf = (float*)volk_malloc(d_fftsize*sizeof(float),
+                                     volk_get_alignment());
 
       buildwindow();
 
@@ -92,10 +95,10 @@ namespace gr {
     sink_c_impl::~sink_c_impl()
     {
       delete d_main_gui;
-      delete [] d_residbuf;
-      delete [] d_magbuf;
       delete d_fft;
       delete d_argv;
+      volk_free(d_residbuf);
+      volk_free(d_magbuf);
     }
 
     bool
@@ -120,9 +123,18 @@ namespace gr {
 	d_qApplication = qApp;
       }
       else {
+        std::string style = prefs::singleton()->get_string("qtgui", "style", "raster");
+        QApplication::setGraphicsSystem(QString(style.c_str()));
 	d_qApplication = new QApplication(d_argc, &d_argv);
       }
 
+      // If a style sheet is set in the prefs file, enable it here.
+      std::string qssfile = prefs::singleton()->get_string("qtgui","qss","");
+      if(qssfile.size() > 0) {
+        QString sstext = get_qt_style_sheet(QString(qssfile.c_str()));
+        d_qApplication->setStyleSheet(sstext);
+      }
+
       if(d_center_freq < 0) {
 	throw std::runtime_error("sink_c_impl: Received bad center frequency.\n");
       }
@@ -160,6 +172,7 @@ namespace gr {
       return d_main_gui->qwidget();
     }
 
+#ifdef ENABLE_PYTHON
     PyObject*
     sink_c_impl::pyqwidget()
     {
@@ -167,6 +180,7 @@ namespace gr {
       PyObject *retarg = Py_BuildValue("N", w);
       return retarg;
     }
+#endif
 
     void
     sink_c_impl::set_fft_size(const int fftsize)
@@ -270,14 +284,16 @@ namespace gr {
       if(newfftsize != d_fftsize) {
 
 	// Resize residbuf and replace data
-	delete [] d_residbuf;
-	d_residbuf = new gr_complex[newfftsize];
+        volk_free(d_residbuf);
+        d_residbuf = (gr_complex*)volk_malloc(newfftsize*sizeof(gr_complex),
+                                              volk_get_alignment());
 
-	delete [] d_magbuf;
-	d_magbuf = new float[newfftsize];
+        volk_free(d_magbuf);
+        d_magbuf = (float*)volk_malloc(newfftsize*sizeof(float),
+                                       volk_get_alignment());
 
-	// Set new fft size and reset buffer index 
-	// (throws away any currently held data, but who cares?) 
+	// Set new fft size and reset buffer index
+	// (throws away any currently held data, but who cares?)
 	d_fftsize = newfftsize;
 	d_index = 0;
 
@@ -326,7 +342,7 @@ namespace gr {
 
 	  j += resid;
 	  fft(d_magbuf, d_residbuf, d_fftsize);
-      
+
 	  d_main_gui->updateWindow(true, d_magbuf, d_fftsize,
 				   NULL, 0, (float*)d_residbuf, d_fftsize,
 				   currentTime, true);
