@@ -49,11 +49,20 @@ SpectrumDisplayForm::SpectrumDisplayForm(QWidget* parent)
   AvgLineEdit->setRange(0, 500);                 // Set range of Average box value from 0 to 500
   minHoldCheckBox_toggled( false );
   maxHoldCheckBox_toggled( false );
-  
+
+#if QWT_VERSION < 0x060100
   WaterfallMaximumIntensitySlider->setRange(-200, 0);
   WaterfallMinimumIntensitySlider->setRange(-200, 0);
   WaterfallMinimumIntensitySlider->setValue(-200);
-  
+#else /* QWT_VERSION < 0x060100 */
+  WaterfallMaximumIntensitySlider->setScale(-200, 0);
+  WaterfallMinimumIntensitySlider->setScale(-200, 0);
+  WaterfallMinimumIntensitySlider->setValue(-200);
+#endif /* QWT_VERSION < 0x060100 */
+
+  WaterfallMaximumIntensitySlider->setOrientation(Qt::Horizontal);
+  WaterfallMinimumIntensitySlider->setOrientation(Qt::Horizontal);
+
   _peakFrequency = 0;
   _peakAmplitude = -HUGE_VAL;
 
@@ -163,12 +172,12 @@ static void fftshift_and_sum(double *outFFT, const float *inFFT,
       peak_ampl = *outptr;
     }
     sum_mean += *outptr;
-    
+
     inptr++;
     outptr++;
   }
-  
-  // This loop takes the first half of the input data and puts it in the 
+
+  // This loop takes the first half of the input data and puts it in the
   // second half of the plotted data
   inptr = inFFT;
   for(uint64_t point = 0; point < num_points/2; point++) {
@@ -606,14 +615,26 @@ void
 SpectrumDisplayForm::waterfallAutoScaleBtnCB()
 {
   double minimumIntensity = _noiseFloorAmplitude - 5;
-  if(minimumIntensity < WaterfallMinimumIntensitySlider->minValue()){
+  double maximumIntensity = _peakAmplitude + 10;
+
+#if QWT_VERSION < 0x060100
+  if(minimumIntensity < WaterfallMinimumIntensitySlider->minValue()) {
     minimumIntensity = WaterfallMinimumIntensitySlider->minValue();
   }
   WaterfallMinimumIntensitySlider->setValue(minimumIntensity);
-  double maximumIntensity = _peakAmplitude + 10;
-  if(maximumIntensity > WaterfallMaximumIntensitySlider->maxValue()){
+  if(maximumIntensity > WaterfallMaximumIntensitySlider->maxValue()) {
     maximumIntensity = WaterfallMaximumIntensitySlider->maxValue();
   }
+#else /* QWT_VERSION < 0x060100 */
+  if(minimumIntensity < WaterfallMinimumIntensitySlider->lowerBound()) {
+    minimumIntensity = WaterfallMinimumIntensitySlider->lowerBound();
+  }
+  WaterfallMinimumIntensitySlider->setValue(minimumIntensity);
+  if(maximumIntensity > WaterfallMaximumIntensitySlider->upperBound()) {
+    maximumIntensity = WaterfallMaximumIntensitySlider->upperBound();
+  }
+#endif /* QWT_VERSION < 0x060100 */
+
   WaterfallMaximumIntensitySlider->setValue(maximumIntensity);
   waterfallMaximumIntensityChangedCB(maximumIntensity);
 }
