@@ -26,12 +26,13 @@
 
 #include "time_raster_sink_f_impl.h"
 #include <gnuradio/io_signature.h>
+#include <gnuradio/prefs.h>
 #include <string.h>
 #include <volk/volk.h>
 
 namespace gr {
   namespace qtgui {
-    
+
     time_raster_sink_f::sptr
     time_raster_sink_f::make(double samp_rate,
 			     double rows, double cols,
@@ -72,18 +73,20 @@ namespace gr {
       // http://harmattan-dev.nokia.com/docs/library/html/qt4/qapplication.html
       d_argc = 1;
       d_argv = new char;
-      d_argv = '\0';
+      d_argv[0] = '\0';
 
       d_main_gui = NULL;
 
       d_index = 0;
 
       d_icols = static_cast<int>(ceil(d_cols));
-      d_tmpflt = fft::malloc_float(d_icols);
+      d_tmpflt = (float*)volk_malloc(d_icols*sizeof(float),
+                                     volk_get_alignment());
       memset(d_tmpflt, 0, d_icols*sizeof(float));
-      
+
       for(int i = 0; i < d_nconnections; i++) {
-	d_residbufs.push_back(fft::malloc_double(d_icols));
+	d_residbufs.push_back((double*)volk_malloc(d_icols*sizeof(double),
+                                                   volk_get_alignment()));
 	memset(d_residbufs[i], 0, d_icols*sizeof(double));
       }
 
@@ -98,9 +101,9 @@ namespace gr {
       if(!d_main_gui->isClosed())
         d_main_gui->close();
 
-      fft::free(d_tmpflt);
+      volk_free(d_tmpflt);
       for(int i = 0; i < d_nconnections; i++) {
-	fft::free(d_residbufs[i]);
+	volk_free(d_residbufs[i]);
       }
 
       delete d_argv;
@@ -119,9 +122,18 @@ namespace gr {
 	d_qApplication = qApp;
       }
       else {
+        std::string style = prefs::singleton()->get_string("qtgui", "style", "raster");
+        QApplication::setGraphicsSystem(QString(style.c_str()));
 	d_qApplication = new QApplication(d_argc, &d_argv);
       }
 
+      // If a style sheet is set in the prefs file, enable it here.
+      std::string qssfile = prefs::singleton()->get_string("qtgui","qss","");
+      if(qssfile.size() > 0) {
+        QString sstext = get_qt_style_sheet(QString(qssfile.c_str()));
+        d_qApplication->setStyleSheet(sstext);
+      }
+
       // Create time raster plot; as a bit input, we expect to see 1's
       // and 0's from each stream, so we set the maximum intensity
       // (zmax) to the number of connections so after adding the
@@ -147,6 +159,7 @@ namespace gr {
       return d_main_gui;
     }
 
+#ifdef ENABLE_PYTHON
     PyObject*
     time_raster_sink_f_impl::pyqwidget()
     {
@@ -154,6 +167,7 @@ namespace gr {
       PyObject *retarg = Py_BuildValue("N", w);
       return retarg;
     }
+#endif
 
     void
     time_raster_sink_f_impl::set_update_time(double t)
@@ -377,12 +391,14 @@ namespace gr {
 	d_cols = cols;
 	d_index = 0;
         d_icols = static_cast<int>(ceil(d_cols));
-	fft::free(d_tmpflt);
-	d_tmpflt = fft::malloc_float(d_icols);
+	volk_free(d_tmpflt);
+	d_tmpflt = (float*)volk_malloc(d_icols*sizeof(float),
+                                       volk_get_alignment());
 	memset(d_tmpflt, 0, d_icols*sizeof(float));
 	for(int i = 0; i < d_nconnections; i++) {
-	  fft::free(d_residbufs[i]);
-	  d_residbufs[i] = fft::malloc_double(d_icols);
+	  volk_free(d_residbufs[i]);
+	  d_residbufs[i] = (double*)volk_malloc(d_icols*sizeof(double),
+                                                volk_get_alignment());
 	  memset(d_residbufs[i], 0, d_icols*sizeof(double));
 	}
       }
@@ -407,7 +423,7 @@ namespace gr {
 	    volk_32f_convert_64f_u(&d_residbufs[n][d_index],
 				   d_tmpflt, resid);
 	  }
-      
+
 	  // Update the plot if its time
 	  if(gr::high_res_timer_now() - d_last_time > d_update_time) {
 	    d_last_time = gr::high_res_timer_now();
