@@ -28,6 +28,7 @@
 #include <gnuradio/io_signature.h>
 #include <gnuradio/block_detail.h>
 #include <gnuradio/buffer.h>
+#include <gnuradio/prefs.h>
 #include <string.h>
 #include <volk/volk.h>
 #include <gnuradio/fft/fft.h>
@@ -35,7 +36,7 @@
 
 namespace gr {
   namespace qtgui {
-    
+
     time_sink_f::sptr
     time_sink_f::make(int size, double samp_rate,
 		      const std::string &name,
@@ -62,12 +63,13 @@ namespace gr {
       // http://harmattan-dev.nokia.com/docs/library/html/qt4/qapplication.html
       d_argc = 1;
       d_argv = new char;
-      d_argv = '\0';
+      d_argv[0] = '\0';
 
       d_main_gui = NULL;
 
       for(int n = 0; n < d_nconnections; n++) {
-	d_buffers.push_back(fft::malloc_double(d_buffer_size));
+	d_buffers.push_back((double*)volk_malloc(d_buffer_size*sizeof(double),
+                                                 volk_get_alignment()));
 	memset(d_buffers[n], 0, d_buffer_size*sizeof(double));
       }
 
@@ -94,7 +96,7 @@ namespace gr {
 
       // d_main_gui is a qwidget destroyed with its parent
       for(int n = 0; n < d_nconnections; n++) {
-	fft::free(d_buffers[n]);
+	volk_free(d_buffers[n]);
       }
 
       delete d_argv;
@@ -113,9 +115,18 @@ namespace gr {
 	d_qApplication = qApp;
       }
       else {
+        std::string style = prefs::singleton()->get_string("qtgui", "style", "raster");
+        QApplication::setGraphicsSystem(QString(style.c_str()));
 	d_qApplication = new QApplication(d_argc, &d_argv);
       }
 
+      // If a style sheet is set in the prefs file, enable it here.
+      std::string qssfile = prefs::singleton()->get_string("qtgui","qss","");
+      if(qssfile.size() > 0) {
+        QString sstext = get_qt_style_sheet(QString(qssfile.c_str()));
+        d_qApplication->setStyleSheet(sstext);
+      }
+
       d_main_gui = new TimeDisplayForm(d_nconnections, d_parent);
       d_main_gui->setNPoints(d_size);
       d_main_gui->setSampleRate(d_samp_rate);
@@ -136,6 +147,7 @@ namespace gr {
       return d_main_gui;
     }
 
+#ifdef ENABLE_PYTHON
     PyObject*
     time_sink_f_impl::pyqwidget()
     {
@@ -143,6 +155,7 @@ namespace gr {
       PyObject *retarg = Py_BuildValue("N", w);
       return retarg;
     }
+#endif
 
     void
     time_sink_f_impl::set_y_axis(double min, double max)
@@ -291,15 +304,16 @@ namespace gr {
       if(newsize != d_size) {
         gr::thread::scoped_lock lock(d_mutex);
 
-	// Set new size and reset buffer index 
-	// (throws away any currently held data, but who cares?) 
+	// Set new size and reset buffer index
+	// (throws away any currently held data, but who cares?)
 	d_size = newsize;
         d_buffer_size = 2*d_size;
 
 	// Resize buffers and replace data
 	for(int n = 0; n < d_nconnections; n++) {
-	  fft::free(d_buffers[n]);
-	  d_buffers[n] = fft::malloc_double(d_buffer_size);
+	  volk_free(d_buffers[n]);
+	  d_buffers[n] = (double*)volk_malloc(d_buffer_size*sizeof(double),
+                                              volk_get_alignment());
 	  memset(d_buffers[n], 0, d_buffer_size*sizeof(double));
 	}
 
