@@ -32,6 +32,8 @@
 # M. Revnell Jan 06
 
 from gnuradio import gr
+from gnuradio import blocks
+from gnuradio import filter
 
 class ssb_demod( gr.hier_block2 ):
     def __init__( self, if_rate, af_rate ):
@@ -46,29 +48,29 @@ class ssb_demod( gr.hier_block2 ):
 
         self.xlate_taps = ([complex(v) for v in file('ssb_taps').readlines()])
 
-        self.audio_taps = gr.firdes.low_pass(
+        self.audio_taps = filter.firdes.low_pass(
             1.0,
             self.af_rate,
             3e3,
             600,
-            gr.firdes.WIN_HAMMING )
+            filter.firdes.WIN_HAMMING )
 
-        self.xlate = gr.freq_xlating_fir_filter_ccc(
+        self.xlate = filter.freq_xlating_fir_filter_ccc(
             self.if_decim,
             self.xlate_taps,
             0,
             self.if_rate )
 
-        self.split = gr.complex_to_float()
+        self.split = blocks.complex_to_float()
 
-        self.lpf = gr.fir_filter_fff(
+        self.lpf = filter.fir_filter_fff(
             1, self.audio_taps )
 
-        self.sum   = gr.add_ff( )
-        self.am_sel = gr.multiply_const_ff( 0 )
-        self.sb_sel = gr.multiply_const_ff( 1 )
-        self.mixer  = gr.add_ff()
-        self.am_det = gr.complex_to_mag()
+        self.sum   = blocks.add_ff( )
+        self.am_sel = blocks.multiply_const_ff( 0 )
+        self.sb_sel = blocks.multiply_const_ff( 1 )
+        self.mixer  = blocks.add_ff()
+        self.am_det = blocks.complex_to_mag()
 
         self.connect(self,             self.xlate)
         self.connect(self.xlate,       self.split)
@@ -93,22 +95,22 @@ class ssb_demod( gr.hier_block2 ):
         self.am_sel.set_k( 0.0 )
 
     def set_am( self ):
-        taps = gr.firdes.low_pass( 1.0,
-                                   self.if_rate,
-                                   5e3,
-                                   2e3,
-                                   gr.firdes.WIN_HAMMING )
+        taps = filter.firdes.low_pass( 1.0,
+                                       self.if_rate,
+                                       5e3,
+                                       2e3,
+                                       filter.firdes.WIN_HAMMING )
         self.xlate.set_taps( taps )
         self.sb_sel.set_k( 0.0 )
         self.am_sel.set_k( 1.0 )
 
     def set_bw( self, bw ):
-        self.audio_taps = gr.firdes.low_pass(
+        self.audio_taps = filter.firdes.low_pass(
             1.0,
             self.af_rate,
             bw,
             600,
-            gr.firdes.WIN_HAMMING )
+            filter.firdes.WIN_HAMMING )
         self.lpf.set_taps( self.audio_taps )
 
     def tune( self, freq ):
