@@ -3,6 +3,7 @@
 #include <boost/foreach.hpp>
 #include <boost/assign/list_of.hpp>
 #include <boost/tokenizer.hpp>
+#include <boost/xpressive/xpressive.hpp>
 #include <iostream>
 #include <vector>
 #include <list>
@@ -93,7 +94,8 @@ volk_type_t volk_type_from_string(std::string name) {
 
     //get the data size
     size_t last_size_pos = name.find_last_of("0123456789");
-    if(last_size_pos < 0) throw std::string("no size spec in type ").append(name);
+    if(last_size_pos == std::string::npos)
+      throw std::string("no size spec in type ").append(name);
     //will throw if malformed
     int size = boost::lexical_cast<int>(name.substr(0, last_size_pos+1));
 
@@ -212,13 +214,37 @@ inline void run_cast_test3_s32fc(volk_fn_3arg_s32fc func, std::vector<void *> &b
     while(iter--) func(buffs[0], buffs[1], buffs[2], scalar, vlen, arch.c_str());
 }
 
+// This function is a nop that helps resolve GNU Radio bugs 582 and 583.
+// Without this the cast in run_volk_tests for tol_i = static_cast<int>(float tol)
+// won't happen on armhf (reported on cortex A9 and A15).
+void lv_force_cast_hf( int tol_i, float tol_f)
+{
+    int diff_i = 1;
+    float diff_f = 1;
+    if( diff_i > tol_i )
+        std::cout << "" ;
+    if( diff_f > tol_f )
+        std::cout << "" ;
+}
+
 template <class t>
 bool fcompare(t *in1, t *in2, unsigned int vlen, float tol) {
     bool fail = false;
     int print_max_errs = 10;
     for(unsigned int i=0; i<vlen; i++) {
-        if(((t *)(in1))[i] < 1e-30) continue; //this is a hack: below around here we'll start to get roundoff errors due to limited precision
-        if(fabs(((t *)(in1))[i] - ((t *)(in2))[i])/(((t *)in1)[i]) > tol) {
+        // for very small numbers we'll see round off errors due to limited 
+        // precision. So a special test case... 
+        if(fabs(((t *)(in1))[i]) < 1e-30) {
+            if( fabs( ((t *)(in2))[i] ) > tol )
+            {
+                fail=true;
+                if(print_max_errs-- > 0) {
+                    std::cout << "offset " << i << " in1: " << t(((t *)(in1))[i]) << " in2: " << t(((t *)(in2))[i]) << std::endl;
+                }
+            }
+        }
+        // the primary test is the percent different greater than given tol
+        else if(fabs(((t *)(in1))[i] - ((t *)(in2))[i])/(((t *)in1)[i]) > tol) {
             fail=true;
             if(print_max_errs-- > 0) {
                 std::cout << "offset " << i << " in1: " << t(((t *)(in1))[i]) << " in2: " << t(((t *)(in2))[i]) << std::endl;
@@ -229,6 +255,38 @@ bool fcompare(t *in1, t *in2, unsigned int vlen, float tol) {
     return fail;
 }
 
+template <class t>
+bool ccompare(t *in1, t *in2, unsigned int vlen, float tol) {
+    bool fail = false;
+    int print_max_errs = 10;
+    for(unsigned int i=0; i<2*vlen; i+=2) {
+        t diff[2] = { in1[i] - in2[i], in1[i+1] - in2[i+1] };
+        t err  = std::sqrt(diff[0] * diff[0] + diff[1] * diff[1]);
+        t norm = std::sqrt(in1[i] * in1[i] + in1[i+1] * in1[i+1]);
+
+        // for very small numbers we'll see round off errors due to limited 
+        // precision. So a special test case... 
+        if (norm < 1e-30) {
+            if (err > tol)
+            {
+                fail=true;
+                if(print_max_errs-- > 0) {
+                    std::cout << "offset " << i/2 << " in1: " << in1[i] << " + " << in1[i+1] << "j  in2: " << in2[i] << " + " << in2[i+1] << "j" << std::endl;
+                }
+            }
+        }
+        // the primary test is the percent different greater than given tol
+        else if((err / norm) > tol) {
+            fail=true;
+            if(print_max_errs-- > 0) {
+                std::cout << "offset " << i/2 << " in1: " << in1[i] << " + " << in1[i+1] << "j  in2: " << in2[i] << " + " << in2[i+1] << "j" << std::endl;
+            }
+        }
+    }
+
+    return fail;
+}
+
 template <class t>
 bool icompare(t *in1, t *in2, unsigned int vlen, unsigned int tol) {
     bool fail = false;
@@ -264,17 +322,31 @@ bool run_volk_tests(volk_func_desc_t desc,
                     int vlen,
                     int iter,
                     std::vector<std::string> *best_arch_vector = 0,
-                    std::string puppet_master_name = "NULL"
+                    std::string puppet_master_name = "NULL",
+                    bool benchmark_mode,
+                    std::string kernel_regex
                    ) {
-    std::cout << "RUN_VOLK_TESTS: " << name << std::endl;
+    boost::xpressive::sregex kernel_expression = boost::xpressive::sregex::compile(kernel_regex);
+    if( !boost::xpressive::regex_search(name, kernel_expression) ) {
+        // in this case we have a regex and are only looking to test one kernel
+        return false;
+    }
+    std::cout << "RUN_VOLK_TESTS: " << name << "(" << vlen << "," << iter << ")" << std::endl;
 
-    const float tol_f = tol;
-    const unsigned int tol_i = static_cast<unsigned int>(tol);
+    // The multiply and lv_force_cast_hf are work arounds for GNU Radio bugs 582 and 583
+    // The bug is the casting/assignment below do not happen, which results in false
+    // positives when testing for errors in fcompare and icompare.
+    // Since this only happens on armhf (reported for Cortex A9 and A15) combined with
+    // the following fixes it is suspected to be a compiler bug. 
+    // Bug 1272024 on launchpad has been filed with Linaro GCC.
+    const float tol_f = tol*1.0000001;
+    const unsigned int tol_i = static_cast<const unsigned int>(tol);
+    lv_force_cast_hf( tol_i, tol_f );
 
     //first let's get a list of available architectures for the test
     std::vector<std::string> arch_list = get_arch_list(desc);
 
-    if(arch_list.size() < 2) {
+    if((!benchmark_mode) && (arch_list.size() < 2)) {
         std::cout << "no architectures to test" << std::endl;
         return false;
     }
@@ -372,8 +444,8 @@ bool run_volk_tests(volk_func_desc_t desc,
         }
 
         end = clock();
-        double arch_time = (double)(end-start)/(double)CLOCKS_PER_SEC;
-        std::cout << arch_list[i] << " completed in " << arch_time << "s" << std::endl;
+        double arch_time = 1000.0 * (double)(end-start)/(double)CLOCKS_PER_SEC;
+        std::cout << arch_list[i] << " completed in " << arch_time << "ms" << std::endl;
 
         profile_times.push_back(arch_time);
     }
@@ -396,9 +468,18 @@ bool run_volk_tests(volk_func_desc_t desc,
             for(size_t j=0; j<both_sigs.size(); j++) {
                 if(both_sigs[j].is_float) {
                     if(both_sigs[j].size == 8) {
-                        fail = fcompare((double *) test_data[generic_offset][j], (double *) test_data[i][j], vlen*(both_sigs[j].is_complex ? 2 : 1), tol_f);
+                        if (both_sigs[j].is_complex) {
+                            fail = ccompare((double *) test_data[generic_offset][j], (double *) test_data[i][j], vlen, tol_f);
+
+                        } else {
+                            fail = fcompare((double *) test_data[generic_offset][j], (double *) test_data[i][j], vlen, tol_f);
+                        }
                     } else {
-                        fail = fcompare((float *) test_data[generic_offset][j], (float *) test_data[i][j], vlen*(both_sigs[j].is_complex ? 2 : 1), tol_f);
+                        if (both_sigs[j].is_complex) {
+                            fail = ccompare((float *) test_data[generic_offset][j], (float *) test_data[i][j], vlen, tol_f);
+                        } else {
+                            fail = fcompare((float *) test_data[generic_offset][j], (float *) test_data[i][j], vlen, tol_f);
+                        }
                     }
                 } else {
                     //i could replace this whole switch statement with a memcmp if i wasn't interested in printing the outputs where they differ
